@@ -8,6 +8,7 @@ from numpy import newaxis
 from numpy import vstack
 from numpy import zeros
 from scipy.integrate import odeint
+from scipy.interpolate import interp1d
 from scipy.linalg import LinAlgWarning
 from sklearn.base import BaseEstimator
 from sklearn.exceptions import ConvergenceWarning
@@ -60,10 +61,6 @@ class SINDy(BaseEstimator):
         one time step. If False, dynamical system is assumed to be a flow
         (right-hand side functions predict continuous time derivatives).
 
-    n_jobs : int, optional (default 1)
-        The number of parallel jobs to use when fitting, predicting with, and
-        scoring the model.
-
     Attributes
     ----------
     model : sklearn.multioutput.MultiOutputRegressor object
@@ -76,6 +73,9 @@ class SINDy(BaseEstimator):
         The total number of output features. This number is a function of
         ``self.n_input_features`` and the feature library being used.
 
+    n_control_features_ : int
+        The total number of control input features.
+
     Examples
     --------
     >>> import numpy as np
@@ -146,7 +146,6 @@ class SINDy(BaseEstimator):
         feature_names=None,
         t_default=1,
         discrete_time=False,
-        n_jobs=1,
     ):
         if optimizer is None:
             optimizer = STLSQ()
@@ -165,7 +164,6 @@ class SINDy(BaseEstimator):
             self.t_default = t_default
         self.feature_names = feature_names
         self.discrete_time = discrete_time
-        self.n_jobs = n_jobs
 
     def fit(
         self,
@@ -187,7 +185,7 @@ class SINDy(BaseEstimator):
             x should be a list containing data for each trajectory. Individual
             trajectories may contain different numbers of samples.
 
-        t: float, numpy array of shape [n_samples], or list of numpy arrays, optional \
+        t: float, numpy array of shape (n_samples,), or list of numpy arrays, optional \
                 (default None)
             If t is a float, it specifies the timestep between each sample.
             If array-like, it specifies the time at which each sample was
@@ -420,7 +418,7 @@ class SINDy(BaseEstimator):
         x: array-like or list of array-like, shape (n_samples, n_input_features)
             Samples
 
-        t: float, numpy array of shape [n_samples], or list of numpy arrays, optional \
+        t: float, numpy array of shape (n_samples,), or list of numpy arrays, optional \
                 (default None)
             Time step between samples or array of collection times. Optional,
             used to compute the time derivatives of the samples if x_dot is not
@@ -560,7 +558,7 @@ class SINDy(BaseEstimator):
         x: array-like or list of array-like, shape (n_samples, n_input_features)
             Data to be differentiated.
 
-        t: int, numpy array of shape [n_samples], or list of numpy arrays, optional \
+        t: int, numpy array of shape (n_samples,), or list of numpy arrays, optional \
                 (default None)
             Time step between samples or array of collection times.
             If None, the default time step ``t_default`` will be used.
@@ -601,7 +599,15 @@ class SINDy(BaseEstimator):
         )
 
     def simulate(
-        self, x0, t, u=None, integrator=odeint, stop_condition=None, **integrator_kws
+        self,
+        x0,
+        t,
+        u=None,
+        integrator=odeint,
+        stop_condition=None,
+        interpolator=None,
+        integrator_kws={},
+        interpolator_kws={},
     ):
         """
         Simulate the SINDy model forward in time.
@@ -618,24 +624,35 @@ class SINDy(BaseEstimator):
 
         u: function from R^1 to R^{n_control_features} or list/array, optional \
             (default None)
-            Control input function.
+            Control inputs.
             If the model is continuous time, i.e. ``self.discrete_time == False``,
             this function should take in a time and output the values of each of
             the n_control_features control features as a list or numpy array.
+            Alternatively, if the model is continuous time, ``u`` can also be an
+            array of control inputs at each time step. In this case the array is
+            fit with the interpolator specified by ``interpolator``.
             If the model is discrete time, i.e. ``self.discrete_time == True``,
             u should be a list (with ``len(u) == t``) or array (with
             ``u.shape[0] == 1``) giving the control inputs at each step.
 
-        integrator: function object, optional
-            Function to use to integrate the system. Default is scipy's odeint.
+        integrator: callable, optional (default ``odeint``)
+            Function to use to integrate the system.
+            Default is ``scipy.integrate.odeint``.
 
         stop_condition: function object, optional
             If model is in discrete time, optional function that gives a
             stopping condition for stepping the simulation forward.
 
-        integrator_kws: dict, optional
+        interpolator: callable, optional (default ``interp1d``)
+            Function used to interpolate control inputs if ``u`` is an array.
+            Default is ``scipy.interpolate.interp1d``.
+
+        integrator_kws: dict, optional (default {})
             Optional keyword arguments to pass to the integrator
 
+        interpolator_kws: dict, optional (default {})
+            Optional keyword arguments to pass to the control input interpolator
+
         Returns
         -------
         x: numpy array, shape (n_samples, n_features)
@@ -699,15 +716,30 @@ class SINDy(BaseEstimator):
                     return self.predict(x[newaxis, :])[0]
 
             else:
-                if ndim(u(1)) == 1:
+                if not callable(u):
+                    if interpolator is None:
+                        u_fun = interp1d(t, u, axis=0, kind="cubic")
+                    else:
+                        u_fun = interpolator(t, u, **interpolator_kws)
+
+                    t = t[:-1]
+                    warnings.warn(
+                        "Last time point dropped in simulation because interpolation"
+                        " of control input was used. To avoid this, pass in a callable"
+                        " for u."
+                    )
+                else:
+                    u_fun = u
+
+                if ndim(u_fun(1)) == 1:
 
                     def rhs(x, t):
-                        return self.predict(x[newaxis, :], u(t).reshape(1, -1))[0]
+                        return self.predict(x[newaxis, :], u_fun(t).reshape(1, -1))[0]
 
                 else:
 
                     def rhs(x, t):
-                        return self.predict(x[newaxis, :], u(t))[0]
+                        return self.predict(x[newaxis, :], u_fun(t))[0]
 
             return integrator(rhs, x0, t, **integrator_kws)
 
