@@ -5,6 +5,7 @@ import numpy as np
 import pytest
 from numpy.linalg import norm
 from sklearn.base import BaseEstimator
+from sklearn.exceptions import ConvergenceWarning
 from sklearn.exceptions import NotFittedError
 from sklearn.linear_model import ElasticNet
 from sklearn.linear_model import Lasso
@@ -82,17 +83,24 @@ def test_fit(data, optimizer):
         assert opt.coef_.shape == (1, x.shape[1])
 
 
-@pytest.mark.parametrize("optimizer", [STLSQ(), SR3()])
+@pytest.mark.parametrize(
+    "optimizer",
+    [STLSQ(), SR3()],
+)
 def test_not_fitted(optimizer):
     with pytest.raises(NotFittedError):
         optimizer.predict(np.ones((1, 3)))
 
 
 @pytest.mark.parametrize("optimizer", [STLSQ(), SR3()])
-def test_complexity_not_fitted(optimizer):
+def test_complexity_not_fitted(optimizer, data_derivative_2d):
     with pytest.raises(NotFittedError):
         optimizer.complexity
 
+    x, _ = data_derivative_2d
+    optimizer.fit(x, x)
+    assert optimizer.complexity > 0
+
 
 @pytest.mark.parametrize(
     "kwargs", [{"normalize": True}, {"fit_intercept": True}, {"copy_X": False}]
@@ -215,9 +223,8 @@ def test_sr3_trimming(data_linear_oscillator_corrupted):
     optimizer_trimming.fit(X, X_dot)
 
     # Check that trimming found the right samples to remove
-    assert (
-        np.sum(np.abs(optimizer_trimming.optimizer.trimming_array - trimming_array))
-        == 0.0
+    np.testing.assert_array_equal(
+        optimizer_trimming.optimizer.trimming_array, trimming_array
     )
 
     # Check that the coefficients found by the optimizer with trimming are closer to
@@ -227,3 +234,37 @@ def test_sr3_trimming(data_linear_oscillator_corrupted):
     assert norm(true_coef - optimizer_trimming.coef_) < norm(
         true_coef - optimizer_without_trimming.coef_
     )
+
+
+def test_sr3_disable_trimming(data_linear_oscillator_corrupted):
+    x, x_dot, _ = data_linear_oscillator_corrupted
+
+    model_plain = SR3()
+    model_plain.fit(x, x_dot)
+
+    model_trimming = SR3(trimming_fraction=0.5)
+    model_trimming.disable_trimming()
+    model_trimming.fit(x, x_dot)
+
+    np.testing.assert_allclose(model_plain.coef_, model_trimming.coef_)
+
+
+def test_sr3_enable_trimming(data_linear_oscillator_corrupted):
+    x, x_dot, _ = data_linear_oscillator_corrupted
+
+    model_plain = SR3()
+    model_plain.enable_trimming(trimming_fraction=0.5)
+    model_plain.fit(x, x_dot)
+
+    model_trimming = SR3(trimming_fraction=0.5)
+    model_trimming.fit(x, x_dot)
+
+    np.testing.assert_allclose(model_plain.coef_, model_trimming.coef_)
+
+
+def test_sr3_warn(data_linear_oscillator_corrupted):
+    x, x_dot, _ = data_linear_oscillator_corrupted
+    model = SR3(max_iter=1, tol=1e-10)
+
+    with pytest.warns(ConvergenceWarning):
+        model.fit(x, x_dot)
